# SatMAD: Satellite Mission Analysis and Design

## Overview 

SatMAD is an open source Python package, aiming at providing the base functionality to solve satellite mission analysis and design as well as orbital mechanics problems with enough precision and performance  to be used in the design and operation of real satellites. The target audience is academics and amateur satellite community, including Cubesats (and anyone else who might be interested).

The focus is on good documentation and good test coverage to produce a reliable flight dynamics library.

Check the source code here: <https://github.com/egemenimre/satmad>

In addition, there is a repository of tutorials, how-to guides and analyses in a dedicated project called SatMAD Applications,
[available at Github as Jupyter notebooks](https://github.com/egemenimre/satmad_applications) and [in plain document format](https://satmad-applications.readthedocs.io/).

## Table of Contents 

```{toctree} 
---
maxdepth: 2
---
about
getting_started
tutorials
doc_index
references
```

## Changelog


```{toctree} 
---
maxdepth: 2
---
changelog
```
